@@ -154,7 +154,7 @@ class MicroBand:
 
     def __init__(self, t=1, n=1, D=1e-5, cb=1e-6, w=5e-4, l=500e-4):
         self.A = w*l
-        self.iLim = 2*np.pi*n*F*self.A*D*C/(w*np.log(64*D*t/w**2))
+        self.iLim = 2*np.pi*n*F*self.A*D*cb/(w*np.log(64*D*t/w**2))
 
 
 if __name__ == '__main__':
